@@ -144,6 +144,8 @@ void fix_desktop_files(char *homedir) {
 		perror("opendir");
 		fprintf(stderr, "Warning: cannot access /usr/share/applications directory, desktop files fixing skipped...\n");
 		free(user_apps_dir);
+		if (dir)
+			closedir(dir);
 		return;
 	}
 
@@ -182,7 +184,9 @@ void fix_desktop_files(char *homedir) {
 		}
 
 		fseek(fp, 0, SEEK_END);
-		size_t size = ftell(fp);
+		long size = ftell(fp);
+		if (size == -1)
+			errExit("ftell");
 		fseek(fp, 0, SEEK_SET);
 		char *buf = malloc(size + 1);
 		if (!buf)
@@ -266,12 +270,16 @@ void fix_desktop_files(char *homedir) {
 
 		if (stat(outname, &sb) == 0) {
 			printf("   %s skipped: file exists\n", filename);
+			if (change_exec)
+				free(change_exec);
 			continue;
 		}
 
 		FILE *fpin = fopen(filename, "r");
 		if (!fpin) {
 			fprintf(stderr, "Warning: cannot open /usr/share/applications/%s\n", filename);
+			if (change_exec)
+				free(change_exec);
 			continue;
 		}
 
@@ -279,6 +287,8 @@ void fix_desktop_files(char *homedir) {
 		if (!fpout) {
 			fprintf(stderr, "Warning: cannot open ~/.local/share/applications/%s\n", outname);
 			fclose(fpin);
+			if (change_exec)
+				free(change_exec);
 			continue;
 		}
 		fprintf(fpout, "# converted by firecfg\n");
